/**********************************************************************************************************************				
Instituto Nacional de Estadstica (INE) www.ine.es				
***********************************************************************************************************************				
				
DESCRIPCIN:				
Este programa genera un fichero SAS con formatos, partiendo de un fichero sin ellos.				
				
Consta de las siguientes partes:				
	* 1. Definir la librera de trabajo --> Libname			
	* 2. Definicin de formatos --> PROC FORMAT			
	* 3. Vincular formatos a la base de datos --> PASO data			
				
 Entrada:                                                           				
     - Fichero SAS sin formatos: 	 EADA_2016.sas7bdat			
 Salida:                                                           				
     - Fichero SAS con formatos: 	 EADA_2016_conFormato.sas7bdat			
				
Donde:				
	* Operacin: Diseo de registro de la Encuesta sobre la Participacin de la Poblacin Adulta en las Actividades de Aprendizaje (EADA_2016)_EADA			
	* Periodo: 2016			
				
************************************************************************************************************************/				
				
/*1) Definir la librera de trabajo: introducir el directorio que desee como librera				
(se da como ejemplo 'C:\Mis resultados'), y copiar en ese directorio el fichero sas "EADA_2016.sas7bdat"*/				
				
libname ROutput 'C:\Mis resultados';			

options fmtsearch = (ROutput ROutput.cat1);

* 2) DEFINICIN DE FORMATOS;
PROC FORMAT LIBRARY=ROutput.cat1;

value $T_CCAA

"01"="Andaluca"
"02"="Aragn"
"03"="Asturias, Principado de"
"04"="Balears, Illes"
"05"="Canarias"
"06"="Cantabria"
"07"="Castilla y Len"
"08"="Castilla-La Mancha"
"09"="Catalua"
"10"="Comunitat Valenciana"
"11"="Extremadura"
"12"="Galicia"
"13"="Madrid, Comunidad de"
"14"="Murcia, Regin de"
"15"="Navarra, Comunidad Foral de"
"16"="Pas Vasco"
"17"="Rioja, La"
"18"="Ceuta"
"19"="Melilla"
;
value $T_SEXO

"1"="Hombre"
"2"="Mujer"
;
value $T_SINO

"1"="S"
"2"="No"
"8"="Negativa/ No sabe"
"9"="No aplicable"
;
value $T_MES

"1"="Enero"
"2"="Febrero"
"3"="Marzo"
"4"="Abril"
"5"="Mayo"
"6"="Junio"
"7"="Julio"
"8"="Agosto"
"9"="Septiembre"
"10"="Octubre"
"11"="Noviembre"
"12"="Diciembre"
"88"="Negativa/ No sabe"
"99"="No aplicable"
;
value $T_1MES

"2"="Febrero"
"3"="Marzo"
;
value $T_ANOS

"1"="Reside en el pas desde hace 1 ao o menos"
"2"="De ms de 1 a 2 aos"
"3"="De ms de 2 a 3 aos"
"4"="De ms de 3 a 4 aos"
"5"="De ms de 4 a 5 aos"
"6"="De ms de 5 a 6 aos"
"7"="De ms de 6 a 7 aos"
"8"="De ms de 7 a 8 aos"
"9"="De ms de 8 a 9 aos"
"10"="De ms de 9 a 10 aos"
"11"="Reside en este pas desde hace mas de 10 aos"
"88"="Negativa/ No sabe"
"99"="No aplicable"
;
value $T_2PAIS

"1"="En Espaa"
"2"="En otro pas"
"8"="Negativa/ No sabe"
;
value $T_SALUD

"1"="Gravemente limitado"
"2"="Limitado, pero no gravemente"
"3"="Nada limitado"
"8"="No sabe"
"9"="No contesta"
;
value $T_2CMDN

"88"="Negativa/ No sabe"
"99"="No aplicable"
;
value N_3CMDN

88="Negativa/ No sabe"
;
value N_EDAD

99="Menores de 18 aos o de 65 o ms aos"
;
value N_4CMDN

8888="Negativa/ No sabe"
9999="No aplicable"
;
value N_6CMDN

888888="Negativa/ No sabe"
999999="No aplicable"
;
value $T_JOBS

"11"="Empresario con asalariados"
"12"="Trabajador autnomo o empresario sin asalariados"
"21"="Asalariado con un trabajo fijo o un contrato de duracin indefinida"
"22"="Asalariado con trabajo temporal o con contrato de trabajo de duracin determinada"
"30"="Ayuda en la empresa o negocio familiar"
"88"="Negativa/ No sabe"
"99"="No aplicable"
;
value $T_1STCN

"11"="Jornada parcial"
"12"="Jornada completa"
"20"="Desempleado"
"31"="Estudiante (incluida experiencia laboral no remunerada)"
"32"="Jubilado (incluido jubilado anticipadamente)"
"33"="Incapacitado permanente"
"35"="Dedicado a las labores del hogar"
"36"="Otra situacin"
"88"="Negativa/ No sabe"
;
value $T_UNIDA

"1"="De 1 a 9 personas"
"2"="De 10 a 19 personas"
"3"="De 20 a 49 personas"
"4"="De 50 a 249 personas"
"5"="De 250 o ms personas"
"7"="No lo sabe pero 10 o ms personas"
"8"="Negativa/ No sabe"
"9"="No aplicable"
;
value $T_1EDUC

"1"="Educacin Primaria"
"2"="Graduado en E. S. O o Graduado escolar (EGB) o Bachiller Elemental"
"3"="Certificados de profesionalidad de nivel 1 y 2 o PCPI"
"4"="Ttulo profesional de msica y danza y similares o Certificado de las escuelas oficiales de idiomas de nivel avanzado"
"5"="Ttulo de Bachillerato, BUP o Bachiller Superior"
"6"="Ttulo de Tcnico de grado medio, o Tcnico auxiliar de FPI o Tcnico Deportivo o de Artes Plsticas o Diseo de grado medio o tcnico militar o Escala bsica de cuerpos policiales"
"7"="Certificado de profesionalidad de nivel 3 o un ttulo propio universitario de 6 meses a menos de 2 aos para el que se requiere bachiller"
"8"="Ttulo de Tcnico superior de FP, Artes Plsticas, Diseo y Deportivas de grado superior o un ttulo propio universitario de 2 aos o ms aos que precisa del ttulo de bachiller"
"9"="Grado universitario de 240 crditos (ECTS), diplomados universitarios o ttulos propios universitarios de experto o especialista"
"10"="Graduados universitario de ms de 240 crditos (ECTS), licenciados, ingenieros, msteres y especialistas de ciencias de la salud (MIR,FIR..)"
"11"="Ttulo de Doctorado"
"88"="Negativa/No sabe"
"99"="No aplicable"
;
value $T_2EDUC

"12"="Enseanzas iniciales de educacin bsica para personas en edad adulta"
"13"="Enseanzas elementales de msica y danza"
"21"="Enseanza secundaria obligatoria ( cursos 1, 2 y 3)"
"22"="Educacin secundaria de adultos y similar"
"23"="Certificados de profesionalidad de nivel 1 y similares"
"31"="Enseanza secundaria obligatoria (4 curso)"
"32"="Enseanzas de bachillerato y similares"
"33"="Enseanzas de formacin profesional, artes plsticas y diseo y deportivas de grado medio y equivalentes"
"34"="Enseanzas profesionales de msica y danza y similares"
"35"="Enseanzas de las escuelas oficiales de idiomas"
"36"="Programas de cualificacin profesional inicial y similares"
"37"="Certificados de profesionalidad de nivel 2 y similares"
"38"="Formacin profesional bsica"
"41"="Certificados de profesionalidad de nivel 3; programas de corta duracin que requieren segunda etapa de educacin secundaria y similares"
"51"="Enseanzas de formacin profesional, artes plsticas y diseo y deportivas de grado superior y equivalentes"
"52"="Ttulos propios universitarios que precisan del ttulo de bachiller, de duracin igual o superior a dos aos"
"61"="Grados universitarios de 240 crditos ECTS y equivalentes"
"62"="Diplomaturas universitarias y equivalentes"
"63"="Ttulos propios universitarios de experto o especialista, de menos de 60 crditos ECTS para titulados universitarios"
"71"="Grados universitarios de ms de 240 crditos ECTS y equivalentes"
"72"="Licenciaturas y equivalentes"
"73"="Msteres oficiales universitarios y equivalentes"
"74"="Especialidades en Ciencias de la Salud por el sistema de residencia y similares"
"75"="Ttulos propios universitarios de mster (maestras), de 60 o ms crditos ECTS para titulados universitarios"
"81"="Doctorado"
"99"="No aplicable"
;
value $T_3EDUC

"1"="Estudios primarios o inferiores (incluido si no sabe leer o escribir)"
"2"="Educacin secundaria obligatoria, Graduado Escolar , Bachiller elemental o equivalentes."
"3"="Bachiller, Bachiller Superior, BUP o Formacin Profesional de Grado Medio o equivalente"
"4"="Estudios Universitarios o Formacin Profesional de Grado Superior o equivalente"
"8"="Negativa /No sabe"
;
value $T_ESTU

"1"="Abandon los estudios antes de su finalizacin"
"2"="Todava est cursando estos estudios"
"3"="Los ha finalizado"
"8"="Negativa/No sabe"
"9"="No aplicable"
;
value $T_FREC

"1"="Con mucha frecuencia"
"2"="Frecuentemente"
"3"="A veces"
"4"="Nunca"
"8"="Negativa/No sabe"
"9"="No aplicable"
;
value $T_2FREC

"1"="Con mucha frecuencia"
"2"="Con cierta frecuencia"
"3"="Con muy poca frecuencia"
"4"="Con ninguna frecuencia"
"8"="Negativa /No sabe"
"9"="No aplicable"
;
value $T_TRBHR

"1"="Slo durante horas de trabajo remuneradas"
"2"="Mayoritariamente durante horas de trabajo remuneradas"
"3"="Mayoritariamente fuera de horas de trabajo remuneradas"
"4"="Slo fuera de horas de trabajo remuneradas"
"5"="No trabajaba en ese momento"
"8"="Negativa /No sabe"
"9"="No aplicable"
;
value $T_GASTO

"1"="Pagado totalmente por usted"
"2"="Pagado en parte por usted y en parte por otra persona o institucin"
"3"="Pagado totalmente por otra persona o institucin"
"4"="La actividad era gratuita"
"5"="No sabe"
"8"="Negativa"
"9"="No aplicable"
;
value $T_CURSO

"1"="Curso terico, charla o conferencia"
"2"="Curso, taller o seminario que combina teora y prctica"
"3"="Actividad planificada para su puesto de trabajo"
"4"="Clases particulares"
"9"="No aplicable"
;
value $T_MOTIV

"1"="Motivos relacionado con el trabajo"
"2"="Motivos personales o no relacionados con el trabajo"
"8"="Negativa/ No sabe"
"9"="No aplicable"
;
value $T_PROVE

"1"="Una institucin de educacin oficial (colegios, institutos, universidades"
"2"="Instituciones de educacin y formacin no oficial ( por ejemplo academias)"
"3"="Instituciones comerciales que no tienen la educacin y la formacin como actividad principal (como los suministradores de equipo)"
"4"="Empleadores"
"5"="Organizaciones empresariales, cmaras de comercio"
"6"="Sindicatos"
"7"="Asociaciones sin fines de lucro (fundaciones, sociedades culturales, partidos polticos)"
"8"="Particulares (como estudiantes que dan clases particulares)"
"9"="Instituciones no comerciales que no tienen la educacin y formacin como actividad principal (bibliotecas, museos, Administraciones Pblicas)"
"10"="Otros organismos"
"88"="Negativa /No sabe"
"99"="No aplicable"
;
value $T_2SINO

"1"="S, es exigido por el empleador o requerido legalmente"
"2"="S, aunque no es exigido por el empleador ni requerido legalmente"
"3"="No (solo se obtiene un certificado de asistencia)"
"8"="Negativa /No sabe"
"9"="No aplicable"
;
value $T_3SINO

"1"="S"
"2"="No o no trabajaba en ese momento"
"8"="Negativa /No sabe"
"9"="No aplicable"
;
value $T_2MOTI

"1"="No reuna los requisitos previos"
"2"="La formacin era demasiado cara o no se lo poda permitir"
"3"="Falta de apoyo del empleador o de los servicios pblicos"
"4"="La formacin no era compatible con el horario de mis tareas o se organiz en un momento inoportuno"
"5"="Las actividades ofrecidas no tenan lugar a una distancia razonable"
"6"="No tenia acceso a un ordenador o Internet"
"7"="No dispona de tiempo por responsabilidades familiares"
"8"="Por problemas de salud"
"9"="Por la edad"
"10"="Tuvo dificultades en encontrar lo que quera"
"11"="Con anterioridad tuvo una mala experiencia en actividades de aprendizaje"
"12"="Otras razones personales"
"88"="Negativa/ No sabe"
"99"="No aplicable"
;
value $T_CNED

"00"="Formacin general, formacin bsica de adultos y habilidades personales"
"01"="Educacin"
"02"="Artes, humanidades y lenguas"
"03"="Ciencias sociales, periodismo y documentacin"
"04"="Negocios, administracin y derecho"
"05"="Ciencias naturales, qumicas, fsicas y matemticas"
"06"="Tecnologas de la informacin y las comunicaciones (TIC)"
"07"="Mecnica, electrnica y otra formacin tcnica; industria y construccin"
"08"="Agricultura, ganadera, pesca, silvicultura y veterinaria"
"09"="Salud y servicios sociales"
"10"="Servicios"
"89"="Sectores desconocidos o no especificados"
"88"="Negativa/ No sabe"
"99"="No aplicable"
;
value $T_NIVEL

"1"="Solamente entiende y usa unas pocas palabras y frases"
"2"="Entiende y usa las expresiones ms comunes. Usa el idioma para las situaciones y cosas familiares"
"3"="Entiende lo esencial del lenguaje comn y redacta textos sencillos. Puede describir experiencias y acontecimientos"
"4"="Entiende una gran variedad de textos complicados y usa el idioma con fluidez. Domina el idioma casi completamente"
"8"="Negativa /No sabe"
"9"="No aplicable"
;
value $T_HOGAR

"1"="Es un hogar unipersonal"
"2"="Vive un padre o madre con algn hijo de menos de 25 aos de edad"
"3"="Vive una pareja sola o sin hijos de menos de 25 aos de edad"
"4"="Vive una pareja con algn hijo de menos de 25 aos de edad"
"5"="Vive una Pareja o un padre o madre con algn hijo de menos de 25 aos de edad y otras personas"
"6"="Es otro tipo de hogar"
"8"="Negativa/ No sabe"
;
value $T_INGRE

"1"="Menos de 650 euros"
"2"="De 650 a menos de 900 euros"
"3"="De 900 a menos de 1200 euros"
"4"="De 1200 a menos de 1500 euros"
"5"="De 1500 a menos de 1800 euros"
"6"="De 1800 a menos de 2100 euros"
"7"="De 2100 a menos de 2500 euros"
"8"="De 2500 a menos de 3000 euros"
"9"="De 3000 a menos de 4000 euros"
"10"="De 4000 euros en adelante"
"88"="Negativa/ No sabe"
;
value $T_ENTRV

"1"="Entrevista personal (CAPI)"
"2"="Entrevista telefnica (CATI)"
"3"="Entrevista por internet (CAWI)"
"4"="Entrevista mixta (CAPI y telefnica)"
;
value $T_URBA

"1"="Zona densamente poblada"
"2"="Zona intermedia"
"3"="Zona poco poblada"
;
value $T_MUNI

"1"="Capital de provincia o con ms de 100.000 habitantes"
"2"="Municipios de 50.001 a 100.000 habitantes"
"3"="Municipios de 20.001 a 50.000 habitantes"
"4"="Municipios de 10.001 a 20.000 habitantes"
"5"="Municipios de 10.000 o menos habitantes"
;
value $T_9CNAE

"01"="Agricultura, ganadera, caza y servicios relacionados con las mismas"
"02"="Silvicultura y explotacin forestal"
"03"="Pesca y acuicultura"
"05"="Extraccin de antracita, hulla y lignito"
"06"="Extraccin de crudo de petrleo y gas natural"
"07"="Extraccin de minerales metlicos"
"08"="Otras industrias extractivas"
"09"="Actividades de apoyo a las industrias extractivas"
"10"="Industria de la alimentacin"
"11"="Fabricacin de bebidas"
"12"="Industria del tabaco"
"13"="Industria textil"
"14"="Confeccin de prendas de vestir"
"15"="Industria del cuero y del calzado"
"16"="Industria de la madera y del corcho, excepto muebles; cestera y espartera"
"17"="Industria del papel"
"18"="Artes grficas y reproduccin de soportes grabados"
"19"="Coqueras y refino de petrleo"
"20"="Industria qumica"
"21"="Fabricacin de productos farmacuticos"
"22"="Fabricacin de productos de caucho y plsticos"
"23"="Fabricacin de otros productos minerales no metlicos"
"24"="Metalurgia; fabricacin de productos de hierro, acero y ferroaleaciones"
"25"="Fabricacin de productos metlicos, excepto maquinaria y equipo"
"26"="Fabricacin de productos informticos, electrnicos y pticos"
"27"="Fabricacin de material y equipo elctrico"
"28"="Fabricacin de maquinaria y equipo n.c.o.p."
"29"="Fabricacin de vehculos de motor, remolques y semirremolques"
"30"="Fabricacin de otro material de transporte"
"31"="Fabricacin de muebles"
"32"="Otras industrias manufactureras"
"33"="Reparacin e instalacin de maquinaria y equipo"
"35"="Suministro de energa elctrica, gas, vapor y aire acondicionado"
"36"="Captacin, depuracin y distribucin de agua"
"37"="Recogida y tratamiento de aguas residuales"
"38"="Recogida, tratamiento y eliminacin de residuos; valorizacin"
"39"="Actividades de descontaminacin y otros servicios de gestin de residuos"
"41"="Construccin de edificios"
"42"="Ingeniera civil"
"43"="Actividades de construccin especializada"
"45"="Venta y reparacin de vehculos de motor y motocicletas"
"46"="Comercio al por mayor e intermediarios del comercio, excepto de vehculos de motor y motocicletas"
"47"="Comercio al por menor, excepto de vehculos de motor y motocicletas"
"49"="Transporte terrestre y por tubera"
"50"="Transporte martimo y por vas navegables interiores"
"51"="Transporte areo"
"52"="Almacenamiento y actividades anexas al transporte"
"53"="Actividades postales y de correos"
"55"="Servicios de alojamiento"
"56"="Servicios de comidas y bebidas"
"58"="Edicin"
"59"="Actividades cinematogrficas, de vdeo y de programas de televisin, grabacin de sonido y edicin musical"
"60"="Actividades de programacin y emisin de radio y televisin"
"61"="Telecomunicaciones"
"62"="Programacin, consultora y otras actividades relacionadas con la informtica"
"63"="Servicios de informacin"
"64"="Servicios financieros, excepto seguros y fondos de pensiones"
"65"="Seguros, reaseguros y fondos de pensiones, excepto Seguridad Social obligatoria"
"66"="Actividades auxiliares a los servicios financieros y a los seguros"
"68"="Actividades inmobiliarias"
"69"="Actividades jurdicas y de contabilidad"
"70"="Actividades de las sedes centrales; actividades de consultora de gestin empresarial"
"71"="Servicios tcnicos de arquitectura e ingeniera; ensayos y anlisis tcnicos"
"72"="Investigacin y desarrollo"
"73"="Publicidad y estudios de mercado"
"74"="Otras actividades profesionales, cientficas y tcnicas"
"75"="Actividades veterinarias"
"77"="Actividades de alquiler"
"78"="Actividades relacionadas con el empleo"
"79"="Actividades de agencias de viajes, operadores tursticos, servicios de reservas y actividades relacionadas con los mismos"
"80"="Actividades de seguridad e investigacin"
"81"="Servicios a edificios y actividades de jardinera"
"82"="Actividades administrativas de oficina y otras actividades auxiliares a las empresas"
"84"="Administracin Pblica y defensa; Seguridad Social obligatoria"
"85"="Educacin"
"86"="Actividades sanitarias"
"87"="Asistencia en establecimientos residenciales"
"88"="Actividades de servicios sociales sin alojamiento"
"90"="Actividades de creacin, artsticas y espectculos"
"91"="Actividades de bibliotecas, archivos, museos y otras actividades culturales"
"92"="Actividades de juegos de azar y apuestas"
"93"="Actividades deportivas, recreativas y de entretenimiento"
"94"="Actividades asociativas"
"95"="Reparacin de ordenadores, efectos personales y artculos de uso domstico"
"96"="Otros servicios personales"
"97"="Actividades de los hogares como empleadores de personal domstico"
"98"="Actividades de los hogares como productores de bienes y servicios para uso propio"
"99"="Actividades de organizaciones y organismos extraterritoriales"
"00"="Negativa/ No sabe"
"89"="No aplicable"
;
value $T_8CIUO

"11"="Directores ejecutivos, personal directivo de la administracin pblica y miembros del poder ejecutivo y de los cuerpos legislativos"
"12"="Directores administradores y comerciales"
"13"="Directores y gerentes de produccin y operaciones"
"14"="Gerentes de hoteles, restaurantes, comercios y otros servicios"
"21"="Profesionales de las ciencias y de la ingeniera"
"22"="Profesionales de la salud"
"23"="Profesionales de la enseanza"
"24"="Especialistas en organizacin de la administracin pblica y de empresas"
"25"="Profesionales de tecnologa de la informacin y las comunicaciones"
"26"="Profesionales en derecho, en ciencias sociales y culturales"
"31"="Profesionales de las ciencias y la ingeniera de nivel medio"
"32"="Profesionales de nivel medio de la salud"
"33"="Profesionales de nivel medio en operaciones financieras y administrativas"
"34"="Profesionales de nivel medio de servicios jurdicos, sociales, culturales y afines"
"35"="Tcnicos de la tecnologa de la informacin y las comunicaciones"
"41"="Oficinistas"
"42"="Empleados en trato directo con el pblico"
"43"="Empleados contables y encargados del registro de materiales"
"44"="Otro personal de apoyo administrativo"
"51"="Trabajadores de los servicios personales"
"52"="Vendedores"
"53"="Trabajadores de los cuidados personales"
"54"="Personal de los servicios de proteccin"
"61"="Agricultores y trabajadores calificados de explotaciones agropecuarias con destino al mercado"
"62"="Trabajadores forestales calificados, pescadores y cazadores"
"63"="Trabajadores agropecuarios, pescadores, cazadores y recolectores de subsistencia"
"71"="Oficiales y operarios de la construccin excluyendo electricistas"
"72"="Oficiales y operarios de la metalurgia, la construccin mecnica y afines"
"73"="Artesanos y operarios de las artes grficas"
"74"="Trabajadores especializados en electricidad y la elecrotecnologa"
"75"="Operarios y oficiales de procesamiento de alimentos, de la confeccin, ebanistas, otros artesanos y afines"
"81"="Operadores de instalaciones fijas y mquinas"
"82"="Ensambladores"
"83"="Conductores de vehculos y operadores de equipos pesados mviles"
"91"="Limpiadores y asistentes"
"92"="Peones agropecuarios, pesqueros y forestales"
"93"="Peones de la minera, la construccin, la industria manufacturera y el transporte"
"94"="Ayudantes de preparacin de alimentos"
"95"="Vendedores ambulantes de servicios y afines"
"96"="Recolectores de desechos y otras ocupaciones elementales"
"01"="Oficiales de las fuerzas armadas"
"02"="Suboficiales de las fuerzas armadas"
"03"="Otros miembros de las fuerzas armadas"
"88"="Negativa /No sabe"
"99"="No aplicable"
;
value $T_EDUCA

"01"="Analfabetos"
"02"="Estudios primarios incompletos"
"10"="Educacin primaria"
"21"="Primera etapa de educacin secundaria sin ttulo de graduado en ESO y similar"
"22"="Primera etapa de educacin secundaria con ttulo de graduado en ESO y equivalentes"
"29"="Certificados de profesionalidad de nivel 1 o nivel 2 y similares (garanta Social, PCPI)"
"32"="Bachillerato y similares"
"33"="Enseanzas de formacin profesional, artes plsticas y diseo y deportivas de grado medio y similares"
"39"="Enseanzas profesionales de msica y danza y similares. Certificado de escuelas oficiales de idiomas de nivel avanzado y similar. Formacin Profesional Bsica (FPB)"
"41"="Certificados de profesionalidad de nivel 3; programas de corta duracin que requieren segunda etapa de secundaria y similares"
"50"="Enseanzas de formacin profesional, artes plsticas y diseo y deportivas de grado superior y equivalentes. Ttulos propios universitarios que precisan del ttulo de bachiller, de duracin igual o superior a dos aos"
"60"="Grados universitarios de 240 crditos ECTS y equivalentes. Diplomados universitarios y equivalentes. Ttulos propios universitarios de experto o especialista, de menos de 60 crditos ECTS para titulados universitarios"
"70"="Grados universitarios de ms de 240 crditos ECTS y equivalentes. Licenciados y equivalentes"
"79"="Msteres oficiales universitarios y equivalentes. Especialidades en Ciencias de la Salud por el sistema de residencia y similares. Ttulos propios universitarios de mster (maestras, de 60 o ms crditos ECTS para titulados universitarios"
"81"="Doctorado universitario"
;
value $T_IDIOM

"ABK"="Abjasia, Abkhaz"
"AFR"="Africaans"
"AKA"="Akan"
"ALB"="Albans"
"AMH"="Amrico"
"ARA"="rabe"
"ARG"="Aragons"
"ARM"="Armenio"
"ASM"="Asams"
"AVA"="Avar, Avaric"
"AVE"="Avestan"
"AYM"="Aimara"
"AZE"="Azerbaiyn"
"BAK"="Bashkir"
"BAM"="Bambara"
"BAQ"="Vasco; Euskera"
"BEL"="Bielorruso"
"BEN"="Bengal"
"BIH"="Bihari, idiomas"
"BIS"="Bislama"
"TIB"="Tibetano"
"BOS"="Bosnio"
"BRE"="Bretn"
"BUL"="Blgaro"
"BUR"="Birmano"
"CAT"="Cataln"
"CZE"="Checo"
"CHA"="Chamorro"
"CHE"="Chechenio"
"CHI"="Chino"
"CHV"="Chuvash"
"COR"="Cornualles"
"COS"="Corso"
"CRE"="Cree"
"WEL"="Gals"
"DAN"="Dans"
"GER"="Alemn"
"DIV"="Divehi; Dhivehi; Maldivas"
"DUT"="Holands; Flamenco"
"DZO"="Dzongkha"
"GRE"="Griego"
"ENG"="Ingls"
"EPO"="Esperanto"
"EST"="Estonio"
"EWE"="Ewe"
"FAO"="Faroese"
"PER"="Persa"
"FIJ"="Fiyiano"
"FIN"="Finlands"
"FRE"="Francs"
"FRY"="Frisn"
"FUL"="Fulah"
"GEO"="Georgiano"
"GLA"="Galico; Galico Escocs"
"GLE"="Irlands"
"GLG"="Gallego"
"GLV"="La Isla De Man"
"GRN"="Guaran"
"GUJ"="Gujarati, guyarat"
"HAT"="Haitano; Creole Haitiano"
"HAU"="Hausa"
"HEB"="Hebreo"
"HER"="Herero"
"HIN"="Hindi"
"HMO"="Hiri Motu"
"HRV"="Croata"
"HUN"="Hngaro"
"IBO"="Igbo"
"ICE"="Islands"
"IDO"="Hago"
"III"="Sichuan Yi; Nuosu"
"IKU"="Inuktitut"
"IND"="Indonesio"
"IPK"="Inupiak"
"ITA"="Italiano"
"JAV"="Javans"
"JPN"="Japons"
"KAL"="Kalaallisut; Groenlandia"
"KAN"="Kannada, Canars"
"KAS"="Cachemira"
"KAU"="Kanuri"
"KAZ"="Kazajo"
"KHM"="Khmer Central"
"KIK"="Kikuyu; Gikuyu"
"KIN"="Kinyarwanda"
"KIR"="Kirguises; Kirguistn"
"KOM"="Komi"
"KON"="Kongo"
"KOR"="Coreano"
"KUA"="Kuanyama; Kwanyama"
"KUR"="Kurdo"
"LAO"="Lao"
"LAT"="Latn"
"LAV"="Letn"
"LIM"="Limburgan; Limburger; Limburgus"
"LIN"="Lingala"
"LIT"="Lituano"
"LTZ"="Luxemburgus"
"LUB"="Luba-Katanga"
"LUG"="Ganda"
"MAH"="Las Islas Marshall"
"MAL"="Malayalam"
"MAO"="Maor"
"MAR"="Marathi"
"MAY"="Malayo"
"MAC"="Macedonio"
"MLG"="Malagasy"
"MLT"="Malts"
"MON"="Mongol"
"NAU"="Nauru"
"NAV"="Navajo; Navajo"
"NBL"="Ndebele Del Sur"
"NDE"="Ndebele, Del Norte"
"NDO"="Ndonga"
"NEP"="Nepal"
"NNO"="Nynorsk, Noruego"
"NOB"="Bokmal, Noruega; Noruego"
"NOR"="Noruego"
"NYA"="Chichewa; Chewa; Nyanja"
"OCI"="Occitano"
"OJI"="Ojibwa"
"ORI"="Oriya"
"ORM"="Oromo"
"OSS"="Osetia; Ossetic"
"PAN"="Panyab; Punjabi"
"PLI"="Pali"
"POL"="Polaco"
"POR"="Portugus"
"PUS"="Pushto; Pashto"
"QUE"="Quechua"
"ROH"="Romanche"
"RUM"="Rumano; Moldavia; Moldavo"
"RUN"="Rundi"
"RUS"="Ruso"
"SAG"="Sango"
"SAN"="Snscrito"
"SIN"="Cingals; Cingaleses"
"SLO"="Eslovaco"
"SLV"="Esloveno"
"SME"="Sami Septentrional"
"SMO"="Samoa"
"SNA"="Shona"
"SND"="Sindhi"
"SOM"="Somal"
"SOT"="Sotho, Southern"
"SPA"="Castellano;Espaol"
"SRD"="Sardo"
"SRP"="Serbio"
"SSW"="Swati"
"SUN"="Sudans"
"SWA"="Swahili"
"SWE"="Sueco"
"TAH"="Tahitian"
"TAM"="Tamil"
"TAT"="Trtaro"
"TEL"="Telugu"
"TGK"="Tayikistn"
"TGL"="Tagalo"
"THA"="Tailands"
"TIR"="Tigria"
"TON"="Tonga (Islas Tonga)"
"TSN"="Tswana"
"TSO"="Tsonga"
"TUK"="Turkmenistn"
"TUR"="Turco"
"TWI"="Twi"
"UIG"="Uigur; Uigur"
"UKR"="Ucranio"
"URD"="Urdu"
"UZB"="Uzbeco"
"VAL"="Valenciano"
"VEN"="Venda"
"VIE"="Vietnamita"
"VOL"="Volapk"
"WLN"="Valn"
"WOL"="Wolof"
"XHO"="Xhosa"
"YID"="Ydish"
"YOR"="Yoruba"
"ZHA"="Zhuang; Chuang"
"ZUL"="Zul"
"000"="Ninguna / No tiene segunda lengua materna"
"999"="No aplicable"
;
value $T_PAIS

"101"="Albania"
"102"="Austria"
"103"="Blgica"
"104"="Bulgaria"
"106"="Chipre"
"107"="Dinamarca"
"108"="Espaa"
"109"="Finlandia"
"110"="Francia"
"111"="Grecia"
"112"="Hungra"
"113"="Irlanda"
"114"="Islandia"
"115"="Italia"
"116"="Liechtenstein"
"117"="Luxemburgo"
"118"="Malta"
"119"="Mnaco"
"120"="Noruega"
"121"="Pases Bajos"
"122"="Polonia"
"123"="Portugal"
"124"="Andorra"
"125"="Reino Unido"
"126"="Alemania"
"128"="Rumana"
"129"="San Marino"
"130"="Santa Sede"
"131"="Suecia"
"132"="Suiza"
"135"="Ucrania"
"136"="Letonia"
"137"="Moldavia"
"138"="Belars"
"139"="Georgia"
"141"="Estonia"
"142"="Lituania"
"143"="Repblica Checa"
"144"="Repblica Eslovaca"
"145"="Bosnia y Herzegovina"
"146"="Croacia"
"147"="Eslovenia"
"148"="Armenia"
"154"="Rusia"
"156"="Macedonia"
"157"="Serbia"
"158"="Montenegro"
"199"="Otros pases de Europa"
"201"="Burkina Faso"
"202"="Angola"
"203"="Argelia"
"204"="Benin"
"205"="Botswana"
"206"="Burundi"
"207"="Cabo Verde"
"208"="Camern"
"209"="Comores"
"210"="Congo"
"211"="Costa de Marfil"
"212"="Djibouti"
"213"="Egipto"
"214"="Etiopa"
"215"="Gabn"
"216"="Gambia"
"217"="Ghana"
"218"="Guinea"
"219"="Guinea-Bissau"
"220"="Guinea Ecuatorial"
"221"="Kenia"
"222"="Lesotho"
"223"="Liberia"
"224"="Libia"
"225"="Madagascar"
"226"="Malawi"
"227"="Mali"
"228"="Marruecos"
"229"="Mauricio"
"230"="Mauritania"
"231"="Mozambique"
"232"="Namibia"
"233"="Nger"
"234"="Nigeria"
"235"="Repblica Centroafricana"
"236"="Sudfrica"
"237"="Ruanda"
"238"="Santo Tom y Prncipe"
"239"="Senegal"
"240"="Seychelles"
"241"="Sierra Leona"
"242"="Somalia"
"243"="Sudn"
"244"="Swazilandia"
"245"="Tanzania"
"246"="Chad"
"247"="Togo"
"248"="Tnez"
"249"="Uganda"
"250"="Repblica Democrtica Congo"
"251"="Zambia"
"252"="Zimbabwe"
"253"="Eritrea"
"254"="Sudn del Sur"
"299"="Otros pases de frica"
"301"="Canad"
"302"="Estados Unidos de Amrica"
"303"="Mxico"
"310"="Antigua y Barbuda"
"311"="Bahamas"
"312"="Barbados"
"313"="Belice"
"314"="Costa Rica"
"315"="Cuba"
"316"="Dominica"
"317"="El Salvador"
"318"="Granada"
"319"="Guatemala"
"320"="Hait"
"321"="Honduras"
"322"="Jamaica"
"323"="Nicaragua"
"324"="Panam"
"325"="San Vicente y las Granadinas"
"326"="Repblica Dominicana"
"327"="Trinidad y Tobago"
"328"="Santa Luca"
"329"="San Cristbal y Nieves"
"340"="Argentina"
"341"="Bolivia"
"342"="Brasil"
"343"="Colombia"
"344"="Chile"
"345"="Ecuador"
"346"="Guyana"
"347"="Paraguay"
"348"="Per"
"349"="Surinam"
"350"="Uruguay"
"351"="Venezuela"
"399"="Otros pases de Amrica"
"401"="Afganistn"
"402"="Arabia Saud"
"403"="Bahrin"
"404"="Bangladesh"
"405"="Myanmar"
"407"="China"
"408"="Emiratos rabes Unidos"
"409"="Filipinas"
"410"="India"
"411"="Indonesia"
"412"="Iraq"
"413"="Irn"
"414"="Israel"
"415"="Japn"
"416"="Jordania"
"417"="Camboya"
"418"="Kuwait"
"419"="Laos"
"420"="Lbano"
"421"="Malasia"
"422"="Maldivas"
"423"="Mongolia"
"424"="Nepal"
"425"="Omn"
"426"="Pakistn"
"427"="Qatar"
"430"="Corea"
"431"="Corea del Norte"
"432"="Singapur"
"433"="Siria"
"434"="Sri Lanka"
"435"="Tailandia"
"436"="Turqua"
"437"="Vietnam"
"439"="Brunei"
"440"="Islas Marshall"
"441"="Yemen"
"442"="Azerbaiyn"
"443"="Kazajstn"
"444"="Kirguistn"
"445"="Tadyikistn"
"446"="Turkmenistn"
"447"="Uzbekistn"
"448"="Bhutn"
"449"="Palestina"
"499"="Otros pases de Asia"
"501"="Australia"
"502"="Fiji"
"504"="Nueva Zelanda"
"505"="Papa Nueva Guinea"
"506"="Islas Salomn"
"507"="Samoa"
"508"="Tonga"
"509"="Vanuatu"
"511"="Micronesia"
"512"="Tuvalu"
"513"="Islas Cook"
"514"="Kiribati"
"515"="Nauru"
"516"="Palaos"
"517"="Timor Oriental"
"599"="Otros pases de Oceana"
"555"="Aptridas (cdigo adicional para nacionalidad)"
"966"="Espaa (Antiguos territorios espaoles_cdigo adicional para pas de nacimiento)"
"888"="Negativa/ No sabe"
"999"="No aplicable"
;




* 3) VINCULAR FORMATOS A LA BASE DE DATOS;
data ROutput.EADA_2016_ConFormato;
	set ROutput.EADA_2016;


FORMAT CCAA $T_CCAA.;
FORMAT REFMONTH $T_1MES.;
FORMAT SEX $T_SEXO.;
FORMAT BIRTHMONTH $T_MES.;
FORMAT EDAD N_EDAD.;
FORMAT CITIZEN $T_PAIS.;
FORMAT SPAIN $T_SINO.;
FORMAT BIRTHPLACE $T_PAIS.;
FORMAT RESTIME $T_ANOS.;
FORMAT BIRTHFATHER $T_2PAIS.;
FORMAT FATHERPLACE $T_PAIS.;
FORMAT BIRTHMOTHER $T_2PAIS.;
FORMAT MOTHERPLACE $T_PAIS.;
FORMAT MARSTADEFACTO $T_SINO.;
FORMAT SALUD $T_SALUD.;
FORMAT MAINSTAT $T_1STCN.;
FORMAT JOBISCO $T_8CIUO.;
FORMAT LOCNACE $T_9CNAE.;
FORMAT JOBSTAT $T_JOBS.;
FORMAT LOCSIZEFIRM $T_UNIDA.;
FORMAT JOBTIME N_4CMDN.;
FORMAT EMP12M $T_SINO.;
FORMAT HATLEVEL $T_EDUCA.;
FORMAT HATFIELD $T_CNED.;
FORMAT HATAGE N_EDAD.;
FORMAT DROPEDUC $T_SINO.;
FORMAT DROPEDUCLEVEL $T_1EDUC.;
FORMAT HATFATHER $T_3EDUC.;
FORMAT HATMOTHER $T_3EDUC.;
FORMAT FEDLEVEL $T_2EDUC.;
FORMAT FEDFIELD $T_CNED.;
FORMAT FEDSTARTYEAR N_4CMDN.;
FORMAT FEDSTARTMONTH $T_MES.;
FORMAT FEDCOMP $T_ESTU.;
FORMAT FEDDIST $T_SINO.;
FORMAT FEDDISTOL $T_SINO.;
FORMAT FEDOERA $T_FREC.;
FORMAT FEDOERB $T_SINO.;
FORMAT FEDREASON_01a $T_SINO.;
FORMAT FEDREASON_01b $T_SINO.;
FORMAT FEDREASON_02 $T_SINO.;
FORMAT FEDREASON_03 $T_SINO.;
FORMAT FEDREASON_04 $T_SINO.;
FORMAT FEDREASON_05 $T_SINO.;
FORMAT FEDREASON_06 $T_SINO.;
FORMAT FEDREASON_07 $T_SINO.;
FORMAT FEDREASON_08 $T_SINO.;
FORMAT FEDREASON_09 $T_SINO.;
FORMAT FEDWORKTIME $T_TRBHR.;
FORMAT FEDNBHOURS N_4CMDN.;
FORMAT FEDPAID $T_GASTO.;
FORMAT FEDPAIDBY_1 $T_SINO.;
FORMAT FEDPAIDBY_2 $T_SINO.;
FORMAT FEDPAIDBY_3 $T_SINO.;
FORMAT FEDPAIDBY_4 $T_SINO.;
FORMAT FEDUSEA $T_2FREC.;
FORMAT FEDUSEB $T_2FREC.;
FORMAT FEDOUTCOME_1 $T_SINO.;
FORMAT FEDOUTCOME_3 $T_SINO.;
FORMAT FEDOUTCOME_2 $T_SINO.;
FORMAT FEDOUTCOME_4 $T_SINO.;
FORMAT FEDOUTCOME_5 $T_SINO.;
FORMAT FEDOUTCOME_6 $T_SINO.;
FORMAT FEDOUTCOME_7 $T_SINO.;
FORMAT NFEGUIDEDJT $T_SINO.;
FORMAT NFEWORKSHOP $T_SINO.;
FORMAT NFECOURSE $T_SINO.;
FORMAT NFELESSON $T_SINO.;

FORMAT NFEACT01_TYPE $T_CURSO.;
FORMAT NFEACT01_PURP $T_MOTIV.;
FORMAT NFEACT01_WORKTIME $T_3SINO.;
FORMAT NFEACT01_PAIDBY $T_3SINO.;
FORMAT NFEACT02_TYPE $T_CURSO.;
FORMAT NFEACT02_PURP $T_MOTIV.;
FORMAT NFEACT02_WORKTIME $T_3SINO.;
FORMAT NFEACT02_PAIDBY $T_3SINO.;
FORMAT NFEACT03_TYPE $T_CURSO.;
FORMAT NFEACT03_PURP $T_MOTIV.;
FORMAT NFEACT03_WORKTIME $T_3SINO.;
FORMAT NFEACT03_PAIDBY $T_3SINO.;
FORMAT NFEACT04_TYPE $T_CURSO.;
FORMAT NFEACT04_PURP $T_MOTIV.;
FORMAT NFEACT04_WORKTIME $T_3SINO.;
FORMAT NFEACT04_PAIDBY $T_3SINO.;
FORMAT NFEACT05_TYPE $T_CURSO.;
FORMAT NFEACT05_PURP $T_MOTIV.;
FORMAT NFEACT05_WORKTIME $T_3SINO.;
FORMAT NFEACT05_PAIDBY $T_3SINO.;
FORMAT NFEACT06_TYPE $T_CURSO.;
FORMAT NFEACT06_PURP $T_MOTIV.;
FORMAT NFEACT06_WORKTIME $T_3SINO.;
FORMAT NFEACT06_PAIDBY $T_3SINO.;
FORMAT NFEACT07_TYPE $T_CURSO.;
FORMAT NFEACT07_PURP $T_MOTIV.;
FORMAT NFEACT07_WORKTIME $T_3SINO.;
FORMAT NFEACT07_PAIDBY $T_3SINO.;
FORMAT NFERAND1 $T_2CMDN.;
FORMAT NFERAND1_TYPE $T_CURSO.;
FORMAT NFEFIELD1 $T_CNED.;
FORMAT NFEDIST1 $T_SINO.;
FORMAT NFEDISTOL1 $T_SINO.;
FORMAT NFEOERA1 $T_SINO.;
FORMAT NFEOERB1 $T_SINO.;
FORMAT NFEREASON1_01a $T_SINO.;
FORMAT NFEREASON1_01b $T_SINO.;
FORMAT NFEREASON1_02 $T_SINO.;
FORMAT NFEREASON1_03 $T_SINO.;
FORMAT NFEREASON1_04 $T_SINO.;
FORMAT NFEREASON1_13 $T_SINO.;
FORMAT NFEREASON1_11 $T_SINO.;
FORMAT NFEREASON1_06 $T_SINO.;
FORMAT NFEREASON1_07 $T_SINO.;
FORMAT NFEREASON1_08 $T_SINO.;
FORMAT NFEREASON1_09 $T_SINO.;
FORMAT NFEREASON1_10 $T_SINO.;
FORMAT NFEREASON1_12 $T_SINO.;
FORMAT NFENBHOURS1 N_4CMDN.;
FORMAT NFEPROVIDER1 $T_PROVE.;
FORMAT NFECERT1 $T_2SINO.;
FORMAT NFEPAID1 $T_GASTO.;
FORMAT NFEPAIDBY1_1 $T_SINO.;
FORMAT NFEPAIDBY1_2 $T_SINO.;
FORMAT NFEPAIDBY1_3 $T_SINO.;
FORMAT NFEPAIDBY1_4 $T_SINO.;
FORMAT NFEPAIDVAL1_A N_6CMDN.;
FORMAT NFEPAIDVAL1_B N_6CMDN.;
FORMAT NFEPAIDVAL1 N_6CMDN.;
FORMAT NFEUSEA1 $T_2FREC.;
FORMAT NFEUSEB1 $T_2FREC.;
FORMAT NFEOUTCOME1_1 $T_SINO.;
FORMAT NFEOUTCOME1_3 $T_SINO.;
FORMAT NFEOUTCOME1_2 $T_SINO.;
FORMAT NFEOUTCOME1_4 $T_SINO.;
FORMAT NFEOUTCOME1_5 $T_SINO.;
FORMAT NFEOUTCOME1_6 $T_SINO.;
FORMAT NFEOUTCOME1_7 $T_SINO.;
FORMAT NFERAND2 $T_2CMDN.;
FORMAT NFERAND2_TYPE $T_CURSO.;
FORMAT NFEFIELD2 $T_CNED.;
FORMAT NFEDIST2 $T_SINO.;
FORMAT NFEDISTOL2 $T_SINO.;
FORMAT NFEOERA2 $T_SINO.;
FORMAT NFEOERB2 $T_SINO.;
FORMAT NFEREASON2_01a $T_SINO.;
FORMAT NFEREASON2_01b $T_SINO.;
FORMAT NFEREASON2_02 $T_SINO.;
FORMAT NFEREASON2_03 $T_SINO.;
FORMAT NFEREASON2_04 $T_SINO.;
FORMAT NFEREASON2_13 $T_SINO.;
FORMAT NFEREASON2_11 $T_SINO.;
FORMAT NFEREASON2_06 $T_SINO.;
FORMAT NFEREASON2_07 $T_SINO.;
FORMAT NFEREASON2_08 $T_SINO.;
FORMAT NFEREASON2_09 $T_SINO.;
FORMAT NFEREASON2_10 $T_SINO.;
FORMAT NFEREASON2_12 $T_SINO.;
FORMAT NFENBHOURS2 N_4CMDN.;
FORMAT NFEPROVIDER2 $T_PROVE.;
FORMAT NFECERT2 $T_2SINO.;
FORMAT NFEPAID2 $T_GASTO.;
FORMAT NFEPAIDBY2_1 $T_SINO.;
FORMAT NFEPAIDBY2_2 $T_SINO.;
FORMAT NFEPAIDBY2_3 $T_SINO.;
FORMAT NFEPAIDBY2_4 $T_SINO.;
FORMAT NFEPAIDVAL2_A N_6CMDN.;
FORMAT NFEPAIDVAL2_B N_6CMDN.;
FORMAT NFEPAIDVAL2 N_6CMDN.;
FORMAT NFEUSEA2 $T_2FREC.;
FORMAT NFEUSEB2 $T_2FREC.;
FORMAT NFEOUTCOME2_1 $T_SINO.;
FORMAT NFEOUTCOME2_3 $T_SINO.;
FORMAT NFEOUTCOME2_2 $T_SINO.;
FORMAT NFEOUTCOME2_4 $T_SINO.;
FORMAT NFEOUTCOME2_5 $T_SINO.;
FORMAT NFEOUTCOME2_6 $T_SINO.;
FORMAT NFEOUTCOME2_7 $T_SINO.;
FORMAT DIFFICULTY_A $T_SINO.;
FORMAT NEEDA $T_SINO.;
FORMAT DIFFICULTY_B $T_SINO.;
FORMAT NEEDB $T_SINO.;
FORMAT DIFFTYPE_01 $T_SINO.;
FORMAT DIFFTYPE_02 $T_SINO.;
FORMAT DIFFTYPE_03 $T_SINO.;
FORMAT DIFFTYPE_04 $T_SINO.;
FORMAT DIFFTYPE_05 $T_SINO.;
FORMAT DIFFTYPE_06 $T_SINO.;
FORMAT DIFFTYPE_07 $T_SINO.;
FORMAT DIFFTYPE_08a $T_SINO.;
FORMAT DIFFTYPE_08b $T_SINO.;
FORMAT DIFFTYPE_10 $T_SINO.;
FORMAT DIFFTYPE_12 $T_SINO.;
FORMAT DIFFTYPE_09 $T_SINO.;
FORMAT DIFFMAIN $T_2MOTI.;
FORMAT SEEKINFO $T_SINO.;
FORMAT GUIDEINSTA $T_SINO.;
FORMAT GUIDEINSTB $T_SINO.;
FORMAT GUIDESOURCE_1 $T_SINO.;
FORMAT GUIDESOURCE_2 $T_SINO.;
FORMAT GUIDESOURCE_3 $T_SINO.;
FORMAT GUIDESOURCE_4 $T_SINO.;
FORMAT GUIDESOURCE_5 $T_SINO.;
FORMAT GUIDETYPE_1 $T_SINO.;
FORMAT GUIDETYPE_2 $T_SINO.;
FORMAT GUIDETYPE_3 $T_SINO.;
FORMAT GUIDETYPE_4 $T_SINO.;
FORMAT GUIDEMODE_1 $T_SINO.;
FORMAT GUIDEMODE_2 $T_SINO.;
FORMAT GUIDEMODE_3 $T_SINO.;
FORMAT GUIDEMODE_4 $T_SINO.;
FORMAT INFFAMILY $T_SINO.;
FORMAT INFMATERIAL $T_SINO.;
FORMAT INFCOMPUTER $T_SINO.;
FORMAT INFMEDIA $T_SINO.;
FORMAT INFMUSEUM $T_SINO.;
FORMAT INFLIBRARIES $T_SINO.;
FORMAT INF $T_SINO.;
FORMAT LANGMOTHER1 $T_IDIOM.;
FORMAT LANGMOTHER2 $T_IDIOM.;
FORMAT LANGUSED N_3CMDN.;
FORMAT LANGUSED_1 $T_IDIOM.;
FORMAT LANGUSED_2 $T_IDIOM.;
FORMAT LANGUSED_3 $T_IDIOM.;
FORMAT LANGUSED_4 $T_IDIOM.;
FORMAT LANGUSED_5 $T_IDIOM.;
FORMAT LANGUSED_6 $T_IDIOM.;
FORMAT LANGUSED_7 $T_IDIOM.;
FORMAT LANGBEST1 $T_IDIOM.;
FORMAT LANGBEST2 $T_IDIOM.;
FORMAT LANGLEVEL1 $T_NIVEL.;
FORMAT LANGLEVEL2 $T_NIVEL.;
FORMAT HHTYPE $T_HOGAR.;
FORMAT HHINCOME1 $T_INGRE.;
FORMAT INTMETHOD1 $T_ENTRV.;
FORMAT DEG_URB $T_URBA.;
FORMAT TAMUN $T_MUNI.;



RUN;
/* FIN PROGRAMA: Microdatos en SAS: EADA_2016.sas*/
